package com.xy.job;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xxl.job.core.biz.model.ReturnT;
import com.xxl.job.core.handler.annotation.XxlJob;
import com.xy.collections.map.JHashMap;
import com.xy.collections.map.JMap;
import com.xy.device.EnumDeviceCharging;
import com.xy.mapper.DeviceChargingMapper;
import com.xy.utils.*;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * 设备管理费job
 */
@Slf4j
@Component
@AllArgsConstructor
public class DeviceChargingJob {

    private DeviceChargingMapper deviceChargingMapper;

    /**
     * 设备管理费过期消息
     *
     * @return
     */
    @XxlJob("deviceChargingTimeout")
    public ReturnT<String> deviceChargingTimeout() {
        String now = DataTime.getSring();
        //即将过期
        FunctionUtils.NoParamsNoResult timeout1 = () -> {
            int day = SysDictUtils.getValue(EnumDeviceCharging.Code.CODE.getCode(), EnumDeviceCharging.N_200.getCode(), Integer.class);
            String end = DataTime.getStringAround(0, 0, day, 0, 0, 0);
            deviceChargingTimeout(now, end, now, 1, 1000);
        };
        //欠费
        FunctionUtils.NoParamsNoResult timeout2 = () -> deviceChargingTimeout(null, now, now, 1, 1000);
        timeout1.run();
        timeout2.run();
        return ReturnT.SUCCESS;
    }

    private void deviceChargingTimeout(String begin, String end, String thisTime, long current, long size) {
        //查询数据
        IPage<Long> longIPage = deviceChargingMapper.deviceChargingTimeout(Page.of(current, size), begin, end);
        List<Long> mercIds = longIPage.getRecords();
        if (!Emptys.check(mercIds)) {
            return;
        }
        //发送消息
        JMap<String, Object> params = new JHashMap<>();
        MsgUtils.sendMsg(15L, mercIds)
                .sms(merc -> new MsgUtils.MsgInfo(merc.getContactPhone(), params))
                .official(userInfo -> new MsgUtils.MsgInfo(userInfo.getMpOpenid(), params))
                .mini(userInfo -> new MsgUtils.MsgInfo(userInfo.getWechatOpenid(), params))
                .builder();
        //下一页
        current++;
        deviceChargingTimeout(begin, end, thisTime, current, size);
    }

}
